@@ -1044,6 +1044,40 @@ class JciHitachiAWSAPI:
         if hitachi_conn_status != "OK":
             raise RuntimeError(f"An error occurred when changing Hitachi password: {hitachi_conn_status}")
 
+    def get_monthly_data(self, months: int, device_name: str) -> List[Dict]:
+        """Get available monthly data (power consumptions).
+
+        Parameters
+        ----------
+        months : int
+            Number of months to get.
+        device_name : str
+            Device name.
+
+        Returns
+        -------
+        list of monthly data dict
+            Available monthly data. The monthly power consumption is calculated by PowerConsumption_Sum / 10.
+        """
+
+        thing = self._things[device_name]
+        current_timestamp_millis = time.time() * 1000
+
+        conn = aws_connection.GetAvailableAggregationMonthlyData(
+            self._aws_tokens,
+            print_response=self.print_response
+        )
+    
+        conn_status, response = conn.get_data(
+            thing.thing_name,
+            int(current_timestamp_millis - months * 2678400000), # 2678400000 ms == 31 days
+            int(current_timestamp_millis)
+        )
+        if conn_status != "OK":
+            raise RuntimeError(f"An error occurred when getting monthly data: {conn_status}")
+
+        return sorted(response["results"]["Data"], key=lambda x: x["Timestamp"])
+
     def refresh_status(self, device_name : Optional[str] = None, refresh_support_code : bool = False, refresh_shadow : bool = False) -> None:
         """Refresh device status from the API.
 
@@ -1054,9 +1088,9 @@ class JciHitachiAWSAPI:
             If None is given, all devices' status will be refreshed,
             by default None.
         refresh_support_code : bool, optional
-            Whether or not to refresh support code.
+            Whether or not to refresh support code, by default False.
         refresh_shadow : bool, optional
-            Whether or not to refresh AWS IoT Shadow.
+            Whether or not to refresh AWS IoT Shadow, by default False.
 
         Raise
         -------
@@ -1111,7 +1145,7 @@ class JciHitachiAWSAPI:
         Returns
         -------
         dict of JciHitachiAWSStatus or JciHitachiStatus.
-            if legacy is True, return a dict of JciHitachiStatus; otherwise, return a dict of JciHitachiAWSStatus instances.
+            If legacy is True, return a dict of JciHitachiStatus; otherwise, return a dict of JciHitachiAWSStatus instances.
         """
         
         statuses = {}
@@ -1151,7 +1185,7 @@ class JciHitachiAWSAPI:
         self._check_before_publish()
 
         thing = self._things[device_name]
-        if status_name not in JciHitachiAWSStatus.compability_mapping[thing.type]:
+        if status_name not in JciHitachiAWSStatus.compatibility_mapping[thing.type]:
             status_name = JciHitachiAWSStatus.convert_old_to_new(thing.type, status_name)
 
         shadow_publish_mapping = {
@@ -1206,6 +1240,7 @@ class JciHitachiAWSAPI:
             if self._mqtt.mqtt_events.device_control_event.wait(timeout=10.0):
                 device_control = self._mqtt.mqtt_events.device_control.get(thing.thing_name)
                 if device_control.get(status_name) == status_value:
+                    thing.status_code._status[status_name] = status_value
                     self._mqtt.mqtt_events.device_control_event.clear()
                     return True
             self._delay()
